#!/usr/bin/python

import sys


sys.path.insert(0,"/usr/lib/dialcentral/")


import dc_glade


dc_glade.run_dialpad()
